# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.create_indexing_schedule_request import CreateIndexingScheduleRequest

class TestCreateIndexingScheduleRequest(unittest.TestCase):
    """CreateIndexingScheduleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateIndexingScheduleRequest:
        """Test CreateIndexingScheduleRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateIndexingScheduleRequest`
        """
        model = CreateIndexingScheduleRequest()
        if include_optional:
            return CreateIndexingScheduleRequest(
                name = 'Daily CSV indexing',
                description = '',
                indexer_rid = 'ri.indexer..instance.indexer-csv-processor',
                target_uri = 'prtc://ri.perceptic..instance.fs-data-lake/documents',
                namespace = 'production',
                target_minimum_version = 1,
                indexing_settings = {
                    'key' : null
                    },
                trigger = perceptic_core_client.models.schedule_trigger.ScheduleTrigger(),
                enabled = True
            )
        else:
            return CreateIndexingScheduleRequest(
                name = 'Daily CSV indexing',
                indexer_rid = 'ri.indexer..instance.indexer-csv-processor',
                target_uri = 'prtc://ri.perceptic..instance.fs-data-lake/documents',
                namespace = 'production',
                trigger = perceptic_core_client.models.schedule_trigger.ScheduleTrigger(),
        )
        """

    def testCreateIndexingScheduleRequest(self):
        """Test CreateIndexingScheduleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.resource_identifier import ResourceIdentifier

class TestResourceIdentifier(unittest.TestCase):
    """ResourceIdentifier unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceIdentifier:
        """Test ResourceIdentifier
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceIdentifier`
        """
        model = ResourceIdentifier()
        if include_optional:
            return ResourceIdentifier(
                resource_identifier = '',
                service_index = 56,
                instance_index = 56,
                type_index = 56,
                service = '',
                instance = '',
                type = '',
                locator = ''
            )
        else:
            return ResourceIdentifier(
        )
        """

    def testResourceIdentifier(self):
        """Test ResourceIdentifier"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
